<?php

if ( ! function_exists( 'justicia_core_team_meta_box_functions' ) ) {
	function justicia_core_team_meta_box_functions( $post_types ) {
		$post_types[] = 'team-member';
		
		return $post_types;
	}
	
	add_filter( 'justicia_mikado_filter_meta_box_post_types_save', 'justicia_core_team_meta_box_functions' );
	add_filter( 'justicia_mikado_filter_meta_box_post_types_remove', 'justicia_core_team_meta_box_functions' );
}

if ( ! function_exists( 'justicia_core_team_scope_meta_box_functions' ) ) {
	function justicia_core_team_scope_meta_box_functions( $post_types ) {
		$post_types[] = 'team-member';
		
		return $post_types;
	}
	
	add_filter( 'justicia_mikado_filter_set_scope_for_meta_boxes', 'justicia_core_team_scope_meta_box_functions' );
}

if ( ! function_exists( 'justicia_core_team_enqueue_meta_box_styles' ) ) {
	function justicia_core_team_enqueue_meta_box_styles() {
		global $post;
		
		if ( $post->post_type == 'team-member' ) {
			wp_enqueue_style( 'mkdf-jquery-ui', get_template_directory_uri() . '/framework/admin/assets/css/jquery-ui/jquery-ui.css' );
		}
	}
	
	add_action( 'justicia_mikado_action_enqueue_meta_box_styles', 'justicia_core_team_enqueue_meta_box_styles' );
}

if ( ! function_exists( 'justicia_core_register_team_cpt' ) ) {
	function justicia_core_register_team_cpt( $cpt_class_name ) {
		$cpt_class = array(
			'JusticiaCore\CPT\Team\TeamRegister'
		);
		
		$cpt_class_name = array_merge( $cpt_class_name, $cpt_class );
		
		return $cpt_class_name;
	}
	
	add_filter( 'justicia_core_filter_register_custom_post_types', 'justicia_core_register_team_cpt' );
}



// Load team shortcodes
if ( ! function_exists( 'justicia_core_include_team_shortcodes_files' ) ) {
	/**
	 * Loades all shortcodes by going through all folders that are placed directly in shortcodes folder
	 */
	function justicia_core_include_team_shortcodes_files() {
		foreach ( glob( JUSTICIA_CORE_CPT_PATH . '/team/shortcodes/*/load.php' ) as $shortcode_load ) {
			include_once $shortcode_load;
		}
	}
	
	add_action( 'justicia_core_action_include_shortcodes_file', 'justicia_core_include_team_shortcodes_files' );
}

if ( ! function_exists( 'justicia_core_get_single_team' ) ) {
	/**
	 * Loads holder template for doctor single
	 */
	function justicia_core_get_single_team() {
		$team_member_id = get_the_ID();
		
		$params = array(
			'sidebar_layout' => justicia_mikado_sidebar_layout(),
			'position'       => get_post_meta( $team_member_id, 'mkdf_team_member_position', true ),
			'birth_date'     => get_post_meta( $team_member_id, 'mkdf_team_member_birth_date', true ),
			'email'          => get_post_meta( $team_member_id, 'mkdf_team_member_email', true ),
			'phone'          => get_post_meta( $team_member_id, 'mkdf_team_member_phone', true ),
			'address'        => get_post_meta( $team_member_id, 'mkdf_team_member_address', true ),
			'education'      => get_post_meta( $team_member_id, 'mkdf_team_member_education', true ),
			'resume'         => get_post_meta( $team_member_id, 'mkdf_team_member_resume', true ),
			'social_icons'   => justicia_core_single_team_social_icons( $team_member_id ),
		);
		
		justicia_core_get_cpt_single_module_template_part( 'templates/single/holder', 'team', '', $params );
	}
}

if ( ! function_exists( 'justicia_core_single_team_social_icons' ) ) {
	function justicia_core_single_team_social_icons( $id ) {
		$social_icons = array();
		
		for ( $i = 1; $i < 6; $i ++ ) {
			$team_icon_pack = get_post_meta( $id, 'mkdf_team_member_social_icon_pack_' . $i, true );
			if ( $team_icon_pack !== '' ) {
				$team_icon_collection = justicia_mikado_icon_collections()->getIconCollection( get_post_meta( $id, 'mkdf_team_member_social_icon_pack_' . $i, true ) );
				$team_social_icon     = get_post_meta( $id, 'mkdf_team_member_social_icon_pack_' . $i . '_' . $team_icon_collection->param, true );
				$team_social_link     = get_post_meta( $id, 'mkdf_team_member_social_icon_' . $i . '_link', true );
				$team_social_target   = get_post_meta( $id, 'mkdf_team_member_social_icon_' . $i . '_target', true );
				
				if ( $team_social_icon !== '' ) {
					$team_icon_params                                 = array();
					$team_icon_params['icon_pack']                    = $team_icon_pack;
					$team_icon_params[ $team_icon_collection->param ] = $team_social_icon;
					$team_icon_params['link']                         = ! empty( $team_social_link ) ? $team_social_link : '';
					$team_icon_params['target']                       = ! empty( $team_social_target ) ? $team_social_target : '_self';
					
					$social_icons[] = justicia_mikado_execute_shortcode( 'mkdf_icon', $team_icon_params );
				}
			}
		}
		
		return $social_icons;
	}
}

if ( ! function_exists( 'justicia_core_get_team_category_list' ) ) {
	function justicia_core_get_team_category_list( $category = '' ) {
		$number_of_columns = 'three';
		$team_member_layout = 'info-bellow';
		
		$params = array(
			'number_of_columns' => $number_of_columns,
			'team_member_layout' => $team_member_layout
		);

		
		if ( ! empty( $category ) ) {
			$params['category'] = $category;
		}
		$html = justicia_mikado_execute_shortcode( 'mkdf_team_list', $params );
	
		
		print justicia_mikado_get_module_part($html);
	}

}


if ( ! function_exists( 'justicia_core_add_team_to_search_types' ) ) {
	function justicia_core_add_team_to_search_types( $post_types ) {
		$post_types['team-member'] = esc_html__( 'Team Member', 'justicia-core' );
		
		return $post_types;
	}
	
	add_filter( 'justicia_mikado_filter_search_post_type_widget_params_post_type', 'justicia_core_add_team_to_search_types' );
}

if ( ! function_exists( 'justicia_core_set_breadcrumbs_output_for_team' ) ) {
	function justicia_core_set_breadcrumbs_output_for_team( $childContent, $delimiter, $before, $after ) {

		if ( is_tax( 'team-category' ) || is_tax( 'team-tag' ) ) {
			$childContent = '';

			$justicia_taxonomy_id        = get_queried_object_id();
			$justicia_taxonomy_type      = is_tax( 'team-tag' ) ? 'team-tag' : 'team-category';
			$justicia_taxonomy           = ! empty( $justicia_taxonomy_id ) ? get_term_by( 'id', $justicia_taxonomy_id, $justicia_taxonomy_type ) : '';
			$justicia_taxonomy_parent_id = isset( $justicia_taxonomy->parent ) && $justicia_taxonomy->parent !== 0 ? $justicia_taxonomy->parent : '';
			$justicia_taxonomy_parent    = $justicia_taxonomy_parent_id !== '' ? get_term_by( 'id', $justicia_taxonomy_parent_id, $justicia_taxonomy_type ) : '';

			if ( ! empty( $justicia_taxonomy_parent ) ) {
				$childContent .= '<a itemprop="url" href="' . get_term_link( $justicia_taxonomy_parent->term_id ) . '">' . $justicia_taxonomy_parent->name . '</a>' . $delimiter;
			}

			if ( ! empty( $justicia_taxonomy ) ) {
				$childContent .= $before . esc_attr( $justicia_taxonomy->name ) . $after;
			}

		} elseif ( is_singular( 'team-item' ) ) {
			$team_categories = wp_get_post_terms( justicia_mikado_get_page_id(), 'team-category' );
			$childContent         = '';

			if ( ! empty( $team_categories ) && count( $team_categories ) ) {
				foreach ( $team_categories as $cat ) {
					$childContent .= '<a itemprop="url" href="' . get_term_link( $cat->term_id ) . '">' . $cat->name . '</a>' . $delimiter;
				}
			}

			$childContent .= $before . get_the_title() . $after;
		}

		return $childContent;
	}

	add_filter( 'justicia_mikado_filter_breadcrumbs_title_child_output', 'justicia_core_set_breadcrumbs_output_for_team', 10, 4 );
}