<?php
namespace JusticiaCore\CPT\Shortcodes\ElementsHolder;

use JusticiaCore\Lib;

class ElementsHolderItem implements Lib\ShortcodeInterface {
	private $base;
	
	function __construct() {
		$this->base = 'mkdf_elements_holder_item';
		add_action( 'vc_before_init', array( $this, 'vcMap' ) );
	}
	
	public function getBase() {
		return $this->base;
	}
	
	public function vcMap() {
		if ( function_exists( 'vc_map' ) ) {
			vc_map(
				array(
					'name'                    => esc_html__( 'Elements Holder Item', 'justicia-core' ),
					'base'                    => $this->base,
					'as_child'                => array( 'only' => 'mkdf_elements_holder' ),
					'as_parent'               => array( 'except' => 'vc_row, vc_accordion' ),
					'content_element'         => true,
					'category'                => esc_html__( 'by JUSTICIA', 'justicia-core' ),
					'icon'                    => 'icon-wpb-elements-holder-item extended-custom-icon',
					'show_settings_on_create' => true,
					'js_view'                 => 'VcColumnView',
					'params'                  => array(
						array(
							'type'        => 'textfield',
							'param_name'  => 'custom_class',
							'heading'     => esc_html__( 'Custom CSS Class', 'justicia-core' ),
							'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS', 'justicia-core' )
						),
						array(
							'type'       => 'colorpicker',
							'param_name' => 'background_color',
							'heading'    => esc_html__( 'Background Color', 'justicia-core' )
						),
						array(
							'type'       => 'attach_image',
							'param_name' => 'background_image',
							'heading'    => esc_html__( 'Background Image', 'justicia-core' )
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'enable_separate_border',
							'heading'    => esc_html__( 'Enable Separate Border', 'justicia-core' ),
							'value'      => array(
								esc_html__( 'No', 'justicia-core' ) => 'no',
								esc_html__( 'Yes', 'justicia-core' ) => 'yes',
							)
						),
						array(
							'type'       => 'colorpicker',
							'param_name' => 'separate_border_color',
							'heading'    => esc_html__( 'Border Color', 'justicia-core' ),
							'dependency' => array('emlement' => 'enable_separate_border', 'value' => 'yes')
						),
						array(
							'type'       => 'textfield',
							'param_name' => 'separate_border_offset',
							'heading'    => esc_html__( 'Border Offset (px)', 'justicia-core' ),
							'description'=> esc_html__('Enter offset to move border away from item, default value is 20px', 'justicia-core'),
							'dependency' => array('emlement' => 'enable_separate_border', 'value' => 'yes')
						),
						array(
							'type'        => 'textfield',
							'param_name'  => 'item_padding',
							'heading'     => esc_html__( 'Padding', 'justicia-core' ),
							'description' => esc_html__( 'Please insert padding in format 0px 10px 0px 10px', 'justicia-core' )
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'horizontal_alignment',
							'heading'    => esc_html__( 'Horizontal Alignment', 'justicia-core' ),
							'value'      => array(
								esc_html__( 'Left', 'justicia-core' )   => 'left',
								esc_html__( 'Right', 'justicia-core' )  => 'right',
								esc_html__( 'Center', 'justicia-core' ) => 'center'
							)
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'vertical_alignment',
							'heading'    => esc_html__( 'Vertical Alignment', 'justicia-core' ),
							'value'      => array(
								esc_html__( 'Middle', 'justicia-core' ) => 'middle',
								esc_html__( 'Top', 'justicia-core' )    => 'top',
								esc_html__( 'Bottom', 'justicia-core' ) => 'bottom'
							)
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'animation',
							'heading'    => esc_html__( 'Animation Type', 'justicia-core' ),
							'value'      => array(
								esc_html__( 'Default (No Animation)', 'justicia-core' )   => '',
								esc_html__( 'Element Grow In', 'justicia-core' )          => 'mkdf-grow-in',
								esc_html__( 'Element Fade In Down', 'justicia-core' )     => 'mkdf-fade-in-down',
								esc_html__( 'Element From Fade', 'justicia-core' )        => 'mkdf-element-from-fade',
								esc_html__( 'Element From Left', 'justicia-core' )        => 'mkdf-element-from-left',
								esc_html__( 'Element From Right', 'justicia-core' )       => 'mkdf-element-from-right',
								esc_html__( 'Element From Top', 'justicia-core' )         => 'mkdf-element-from-top',
								esc_html__( 'Element From Bottom', 'justicia-core' )      => 'mkdf-element-from-bottom',
								esc_html__( 'Element Flip In', 'justicia-core' )          => 'mkdf-flip-in',
								esc_html__( 'Element X Rotate', 'justicia-core' )         => 'mkdf-x-rotate',
								esc_html__( 'Element Z Rotate', 'justicia-core' )         => 'mkdf-z-rotate',
								esc_html__( 'Element Y Translate', 'justicia-core' )      => 'mkdf-y-translate',
								esc_html__( 'Element Fade In X Rotate', 'justicia-core' ) => 'mkdf-fade-in-left-x-rotate',
							)
						),
						array(
							'type'       => 'textfield',
							'param_name' => 'animation_delay',
							'heading'    => esc_html__( 'Animation Delay (ms)', 'justicia-core' )
						),
						array(
							'type'        => 'textfield',
							'param_name'  => 'item_padding_1367_1600',
							'heading'     => esc_html__( 'Padding on screen size between 1367px-1600px', 'justicia-core' ),
							'description' => esc_html__( 'Please insert padding in format top right bottom left. For example 10px 0 10px 0', 'justicia-core' ),
							'group'       => esc_html__( 'Width & Responsiveness', 'justicia-core' )
						),
						array(
							'type'        => 'textfield',
							'param_name'  => 'item_padding_1025_1366',
							'heading'     => esc_html__( 'Padding on screen size between 1025px-1366px', 'justicia-core' ),
							'description' => esc_html__( 'Please insert padding in format top right bottom left. For example 10px 0 10px 0', 'justicia-core' ),
							'group'       => esc_html__( 'Width & Responsiveness', 'justicia-core' )
						),
						array(
							'type'        => 'textfield',
							'param_name'  => 'item_padding_769_1024',
							'heading'     => esc_html__( 'Padding on screen size between 768px-1024px', 'justicia-core' ),
							'description' => esc_html__( 'Please insert padding in format 0px 10px 0px 10px', 'justicia-core' ),
							'group'       => esc_html__( 'Width & Responsiveness', 'justicia-core' )
						),
						array(
							'type'        => 'textfield',
							'param_name'  => 'item_padding_681_768',
							'heading'     => esc_html__( 'Padding on screen size between 680px-768px', 'justicia-core' ),
							'description' => esc_html__( 'Please insert padding in format 0px 10px 0px 10px', 'justicia-core' ),
							'group'       => esc_html__( 'Width & Responsiveness', 'justicia-core' )
						),
						array(
							'type'        => 'textfield',
							'param_name'  => 'item_padding_680',
							'heading'     => esc_html__( 'Padding on screen size bellow 680px', 'justicia-core' ),
							'description' => esc_html__( 'Please insert padding in format 0px 10px 0px 10px', 'justicia-core' ),
							'group'       => esc_html__( 'Width & Responsiveness', 'justicia-core' )
						)
					)
				)
			);
		}
	}
	
	public function render( $atts, $content = null ) {
		$args   = array(
			'custom_class'           => '',
			'background_color'       => '',
			'background_image'       => '',
			'enable_separate_border' => 'no',
			'separate_border_color'  => '',
			'separate_border_offset' => '',
			'item_padding'           => '',
			'horizontal_alignment'   => '',
			'vertical_alignment'     => '',
			'animation'              => '',
			'animation_delay'        => '',
			'item_padding_1367_1600' => '',
			'item_padding_1025_1366' => '',
			'item_padding_769_1024'  => '',
			'item_padding_681_768'   => '',
			'item_padding_680'       => ''
		);
		$params = shortcode_atts( $args, $atts );
		
		$params['content']           = $content;
		$params['holder_classes']    = $this->getHolderClasses( $params );
		$params['holder_rand_class'] = 'mkdf-eh-custom-' . mt_rand( 1000, 10000 );
		$params['holder_styles']     = $this->getHolderStyles( $params );
		$params['content_styles']    = $this->getContentStyles( $params );
		$params['holder_data']       = $this->getHolderData( $params );
		$params['separate_border_style'] = $this->getBorderStyles( $params );
		
		$html = justicia_core_get_shortcode_module_template_part( 'templates/elements-holder-item-template', 'elements-holder', '', $params );
		
		return $html;
	}
	
	private function getHolderClasses( $params ) {
		$holderClasses = array();
		
		$holderClasses[] = ! empty( $params['custom_class'] ) ? esc_attr( $params['custom_class'] ) : '';
		$holderClasses[] = ! empty( $params['vertical_alignment'] ) ? 'mkdf-vertical-alignment-' . $params['vertical_alignment'] : '';
		$holderClasses[] = ( $params['enable_separate_border'] == 'yes' ) ? 'mkdf-ehi-separate-border-enabled' : '';
		$holderClasses[] = ! empty( $params['horizontal_alignment'] ) ? 'mkdf-horizontal-alignment-' . $params['horizontal_alignment'] : '';
		$holderClasses[] = ! empty( $params['animation'] ) ? $params['animation'] : '';
		
		return implode( ' ', $holderClasses );
	}
	
	private function getHolderStyles( $params ) {
		$styles = array();
		
		if ( ! empty( $params['background_color'] ) ) {
			$styles[] = 'background-color: ' . $params['background_color'];
		}
		
		if ( ! empty( $params['background_image'] ) ) {
			$styles[] = 'background-image: url(' . wp_get_attachment_url( $params['background_image'] ) . ')';
		}
		
		return implode( ';', $styles );
	}
	
	private function getContentStyles( $params ) {
		$styles = array();
		
		if ( $params['item_padding'] !== '' ) {
			$styles[] = 'padding: ' . $params['item_padding'];
		}
		
		return implode( ';', $styles );
	}
	
	private function getHolderData( $params ) {
		$data                    = array();
		$data['data-item-class'] = $params['holder_rand_class'];
		
		if ( ! empty( $params['animation'] ) ) {
			$data['data-animation'] = $params['animation'];
		}
		
		if ( $params['animation_delay'] !== '' ) {
			$data['data-animation-delay'] = esc_attr( $params['animation_delay'] );
		}
		
		if ( $params['item_padding_1367_1600'] !== '' ) {
			$data['data-1367-1600'] = $params['item_padding_1367_1600'];
		}
		
		if ( $params['item_padding_1025_1366'] !== '' ) {
			$data['data-1025-1366'] = $params['item_padding_1025_1366'];
		}
		
		if ( $params['item_padding_769_1024'] !== '' ) {
			$data['data-769-1024'] = $params['item_padding_769_1024'];
		}
		
		if ( $params['item_padding_681_768'] !== '' ) {
			$data['data-681-768'] = $params['item_padding_681_768'];
		}
		
		if ( $params['item_padding_680'] !== '' ) {
			$data['data-680'] = $params['item_padding_680'];
		}
		
		return $data;
	}

	private function getBorderStyles( $params ) {
		$styles = array();

		if ( ! empty( $params['separate_border_color'] ) ) {
			$styles[] = 'border-color: ' . $params['separate_border_color'];
		}

		if ( ! empty( $params['separate_border_offset'] ) ) {
			$styles[] = 'top: -' . justicia_mikado_filter_px($params['separate_border_offset']).'px';
			$styles[] = 'left: -' . justicia_mikado_filter_px($params['separate_border_offset']).'px';
			$styles[] = 'right: -' . justicia_mikado_filter_px($params['separate_border_offset']).'px';
			$styles[] = 'bottom: -' . justicia_mikado_filter_px($params['separate_border_offset']).'px';
		}

		return implode( ';', $styles );
	}
}
