<?php
namespace JusticiaCore\CPT\Shortcodes\VerticalTimeline;

use JusticiaCore\Lib;

class VerticalTimeline implements Lib\ShortcodeInterface {
	private $base;
	
	function __construct() {
		$this->base = 'mkdf_vertical_timeline';
		
		add_action( 'vc_before_init', array( $this, 'vcMap' ) );
	}
	
	public function getBase() {
		return $this->base;
	}
	
	public function vcMap() {
		if ( function_exists( 'vc_map' ) ) {
			vc_map(
				array(
					'name'     => esc_html__( 'Vertical Timeline', 'justicia-core' ),
					'base'     => $this->getBase(),
					'category' => esc_html__( 'by JUSTICIA', 'justicia-core' ),
					'icon'     => 'icon-wpb-vertical-timeline extended-custom-icon',
					'params'   => array(
						array(
							'type'        => 'textfield',
							'param_name'  => 'title',
							'heading'     => esc_html__( 'Title', 'justicia-core' )
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'title_tag',
							'heading'     => esc_html__( 'Title Tag', 'justicia-core' ),
							'value'       => array_flip( justicia_mikado_get_title_tag( true ) ),
							'dependency'  => array( 'element' => 'title', 'not_empty' => true )
						),
						array(
							'type'       => 'param_group',
							'param_name' => 'timeline_items',
							'heading'    => esc_html__( 'Items', 'justicia-core' ),
							'params'     => array(
								array(
									'type'       => 'textfield',
									'param_name' => 'year',
									'heading'    => esc_html__( 'Year', 'justicia-core' )
								),
								array(
									'type'       => 'textfield',
									'param_name' => 'title',
									'heading'    => esc_html__( 'Title', 'justicia-core' ),
								),
								array(
									'type'       => 'textarea',
									'param_name' => 'text',
									'heading'    => esc_html__( 'Text', 'justicia-core' ),
								),
							)
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'items_title_tag',
							'heading'     => esc_html__( 'Timeline Items Title Tag', 'justicia-core' ),
							'value'       => array_flip( justicia_mikado_get_title_tag( true ) )
						),
						array(
							'type'        => 'textfield',
							'param_name'  => 'link',
							'heading'     => esc_html__( 'Link', 'justicia-core' )
						),
						array(
							'type'        => 'textfield',
							'param_name'  => 'link_text',
							'heading'     => esc_html__( 'Link Text', 'justicia-core' ),
							'dependency'  => array( 'element' => 'link', 'not_empty' => true)
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'link_target',
							'heading'     => esc_html__( 'Link Target', 'justicia-core' ),
							'value'       => array_flip( justicia_mikado_get_link_target_array() ),
							'dependency'  => array( 'element' => 'link', 'not_empty' => true),
							'save_always' => true
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'loading_fx',
							'heading'    => esc_html__( 'Enable Loading Effect', 'justicia-core' ),
							'value'      => array_flip( justicia_mikado_get_yes_no_select_array( false, true ) ),
						),
					)
				)
			);
		}
	}
	
	public function render( $atts, $content = null ) {
		$args   = array(
			'title'				=> '',
			'title_tag'			=> 'h3',
			'items_title_tag'	=> 'h4',
			'timeline_items'	=> '',
			'link'				=> '',
			'link_text'			=> '',
			'link_target'		=> '_self',
			'loading_fx'		=> 'yes'
		);
		$params = shortcode_atts( $args, $atts );
		
		$params['holder_classes']      = $this->getHolderClasses( $params, $args );
		$params['timeline_items']      = json_decode( urldecode( $params['timeline_items'] ), true );
		$params['button_params']       = $this->getButtonParams($params);

		$html = justicia_core_get_shortcode_module_template_part( 'templates/vertical-timeline', 'vertical-timeline', '', $params );
		
		return $html;
	}
	
	private function getHolderClasses( $params, $args ) {
		$holderClasses = array();

		$holderClasses[] = ($params['loading_fx'] == 'yes') ? 'mkdf-with-loading-fx' : '';
		
		return implode( ' ', $holderClasses );
	}

	private function getButtonParams( $params ) {
		$button_params = array();

		if ($params['link'] !== '') {
			$button_params['type'] = 'simple';
			$button_params['link'] = $params['link'];

			if ($params['link_text'] !== '') {
				$button_params['text'] = $params['link_text'];
			}

			if ($params['link_target'] !== '') {
				$button_params['target'] = $params['link_target'];
			}
		}

		return $button_params;
	}
}